# Lumeny

This is lumeny, a cli project that I used for my own daily usage.

There are several aspects that I want my cli app grows:

1. Connect to caldav so that it can reminds me of my events, or add new events in cli convinently. Pushing notification to the KDE desktop is also a important part to remind me of the events.
2. Connect to my RSS reader miniflux and filter the most important feeds using ChatGPT (A small recommendation system).
3. A TUI based on textual to help me manage several aspects of point 1 and 2, like inspect upcoming events or get general statistic of my feeds, and help me gradually improve the recommandation algorithm.

